@@ -133,7 +133,7 @@
   WSGIappLocaleSet()->setLocaleString("SJIS","U3:WSSTR Class library","NXCu");
   WSGIappLocaleSet()->setLocaleString("SJIS","V3:WSSTR  Generate class library"," NXCuɂ");
   WSGIappLocaleSet()->setLocaleString("SJIS","W3:WSSTR Compiler","RpC");
-  WSGIappLocaleSet()->setLocaleString("SJIS","X3:WSSTR Runtime mode,Debug mode","ʏ탂[h,fobO[h");
+  WSGIappLocaleSet()->setLocaleString("SJIS","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","ʏ탂[h,fobO[h,ʏX^eBbN[h,fobOX^eBbN[h");
   WSGIappLocaleSet()->setLocaleString("SJIS","Y3:WSSTR Include path","ʃCN[hpX");
   WSGIappLocaleSet()->setLocaleString("SJIS","Z3:WSSTR Compiler flags","ʃRpCtO");
   WSGIappLocaleSet()->setLocaleString("SJIS","a3:WSSTR Include path","fobOpCN[hpX");
@@ -246,4 +246,7 @@
   WSGIappLocaleSet()->setLocaleString("SJIS","P3:WSSTR Python(DBG)","Python(DBG)");
   WSGIappLocaleSet()->setLocaleString("SJIS","P3:WSSTR Perl","Perl");
   WSGIappLocaleSet()->setLocaleString("SJIS","P3:WSSTR Perl(DBG)","Perl(DBG)");
+  WSGIappLocaleSet()->setLocaleString("SJIS","f3:WSSTR Static option","DLLrh");
+  WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Statically linked","X^eBbNN(DLL )");
+  WSGIappLocaleSet()->setLocaleString("SJIS","l3:WSSTR Dynamically linked","_Ci~bNN(DLL )");
 
