@@ -133,7 +133,7 @@
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","U3:WSSTR Class library","クラスライブラリ");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","V3:WSSTR  Generate class library"," クラスライブラリにする");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","W3:WSSTR Compiler","コンパイラ");
-  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X3:WSSTR Runtime mode,Debug mode","通常モード,デバッグモード");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","通常モード,デバッグモード,通常スタティックモード,デバッグスタティックモード");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","Y3:WSSTR Include path","個別インクルードパス");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","Z3:WSSTR Compiler flags","個別コンパイルフラグ");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","a3:WSSTR Include path","デバッグ用インクルードパス");
@@ -246,3 +246,6 @@
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","P3:WSSTR Python(DBG)","Python(DBG)");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","P3:WSSTR Perl","Perl");
   WSGIappLocaleSet()->setLocaleString("UTF8_JP","P3:WSSTR Perl(DBG)","Perl(DBG)");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","f3:WSSTR Static option","DLL無しビルド");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Statically linked","スタティックリンク(DLL 無し)");
+  WSGIappLocaleSet()->setLocaleString("UTF8_JP","l3:WSSTR Dynamically linked","ダイナミックリンク(DLL あり)");
