@@ -133,7 +133,7 @@
   WSGIappLocaleSet()->setLocaleString("EUCJP","U3:WSSTR Class library","饹饤֥");
   WSGIappLocaleSet()->setLocaleString("EUCJP","V3:WSSTR  Generate class library"," 饹饤֥ˤ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","W3:WSSTR Compiler","ѥ");
-  WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Runtime mode,Debug mode","̾⡼,ǥХå⡼");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","X3:WSSTR Runtime mode,Debug mode,Runtime static mode,Debug static mode","̾⡼,ǥХå⡼,̾凉ƥå⡼,ǥХåƥå⡼");
   WSGIappLocaleSet()->setLocaleString("EUCJP","Y3:WSSTR Include path","̥󥯥롼ɥѥ");
   WSGIappLocaleSet()->setLocaleString("EUCJP","Z3:WSSTR Compiler flags","̥ѥե饰");
   WSGIappLocaleSet()->setLocaleString("EUCJP","a3:WSSTR Include path","ǥХåѥ󥯥롼ɥѥ");
@@ -246,3 +246,6 @@
   WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Python(DBG)","Python(DBG)");
   WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Perl","Perl");
   WSGIappLocaleSet()->setLocaleString("EUCJP","P3:WSSTR Perl(DBG)","Perl(DBG)");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","f3:WSSTR Static option","DLL̵ӥ");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Statically linked","ƥå(DLL ̵)");
+  WSGIappLocaleSet()->setLocaleString("EUCJP","l3:WSSTR Dynamically linked","ʥߥå(DLL )");
