@@ -51,7 +51,7 @@ void* operator new(unsigned int size){
     memflg = 1;
     memset(ptr,0,size);
     if (memlist == NULL){
-      memlist = new WSClistData(64);
+      memlist = new WSClistData(8192);
     }
     memlist->add(ptr);
 //printf("new mem cnt=%d\n",memlist->getNum());
@@ -71,7 +71,7 @@ assert(0);
 fprintf(stderr,"memfree error...\n");
       }
     }
-printf("del mem cnt=%d\n",memlist->getNum());
+//printf("del mem cnt=%d\n",memlist->getNum());
     memflg = 0;
   }
   free(ptr);
@@ -87,7 +87,7 @@ assert(0);
 fprintf(stderr,"memfree error...\n");
       }
     }
-printf("del mem cnt=%d\n",memlist->getNum());
+//printf("del mem cnt=%d\n",memlist->getNum());
     memflg = 0;
   }
   free(ptr);
@@ -2040,7 +2040,6 @@ void WSCbase::_exec_procedure(WSCprocedure** opl,char* opname){
       }
     }
     _exec_procedure(op);
-    _exec_procedure(op);
   }
   delete oplist;
   delete oplist2;
