@@ -54,7 +54,7 @@ WSCform::WSCform(WSCbase* base,char* objname):WSCbase(base,objname){
   _bp_color = -1;
   _shadow_type = WS_SHADOW_OUT;
   _sensitive = True;
-  _pixmap_style = WS_DIRECT_WINDOW;
+  _pixmap_style = WS_DYNAMIC_PIXMAP;
   _no_refresh = False;
   _mouse_no     = 0;
   _grad_no     = 0;
@@ -150,7 +150,7 @@ WSMFproperty(WSCform,WSNbackPixmap, short, _bp_color, -1);
 WSMFproperty(WSCform,WSNshadowType, char,    _shadow_type ,WS_SHADOW_OUT );
 WSMFproperty(WSCform,WSNvis,WSCbool, _vis ,False  );
 WSMFproperty(WSCform,WSNdet,WSCbool, _sensitive, True );
-WSMFproperty(WSCform,WSNpixmapStyle, WSCuchar, _pixmap_style ,WS_DIRECT_WINDOW);
+WSMFproperty(WSCform,WSNpixmapStyle, WSCuchar, _pixmap_style ,WS_DYNAMIC_PIXMAP);
 WSMFproperty(WSCform, WSNmouse,   WSCushort,     _mouse_no     ,0);
 WSMFproperty(WSCform, WSNgradation, WSCuchar, _grad_no   ,0);
 WSMFproperty(WSCform, WSNgradationMargin, WSCuchar, _grad_margin ,0);
