@@ -245,3 +245,6 @@ void WSDappDev::delMenu(WSCbase* menu){
 WSClistData& WSDappDev::getMenuList(){
   return _pld_menu_list;
 }
+void WSDappDev::exit(long val){
+  ::exit(val);
+}
