@@ -8,6 +8,40 @@ typedef unsigned long  WSCulong;
 typedef unsigned char  WSCuchar;
 typedef unsigned int   WSCuint;
 
+#define WS_DATA_SOURCE_NONE      0
+#define WS_DATA_SOURCE_INSTANCE  1
+#define WS_DATA_SOURCE_FILE      2
+
+#define WS_TEXT    0
+#define WS_BINARY  1
+
+#define WS_NORMAL  0
+#define WS_TREE    1
+#define WS_VERBOSE 2
+
+#define WS_HAVE_CHILD   1
+#define WS_HAVE_BROS    2
+
+#define WS_OPEN          0
+#define WS_INDENT_LEVEL  1
+#define WS_ABSOLUTE_OPEN 2
+#define WS_ICON          3
+
+#define WS_SFORM_FIXED          0
+#define WS_SFORM_UNDER_RESIZING 1
+
+#define WS_EXEC_NONE      0
+#define WS_EXEC_RD        1
+#define WS_EXEC_RDWR      2
+#define WS_EXEC_WR        3
+
+#define WS_DOUBLE_CLICK_TIME    300
+
+#define WS_POLICY_ORIGINAL   1
+#define WS_POLICY_WINDOWS    2
+#define WS_POLICY_GRADATION  4
+#define WS_POLICY_AQUA       8
+
 typedef struct {
   long x, y;
   inline void setPoint(long vx,long vy){
@@ -60,6 +94,11 @@ struct WSCrect {
 #define WS_EN_EUCCN       40
 #define WS_EN_BIG5        50
 
+#define WS_DIALOG_CANCEL  0
+#define WS_DIALOG_OK      1
+#define WS_DIALOG_NO      2
+#define WS_DIALOG_DONE    3
+
 class WSCstring {
   public:
     WSCstring(char*);
@@ -75,6 +114,7 @@ class WSCvariant {
     WSCvariant(double);
     WSCvariant(const WSCvariant&);
     WSCvariant(char*);
+    WSCvariant(WSCbase*);
     WSCvariant();
 
     virtual ~WSCvariant();
@@ -90,10 +130,12 @@ class WSCvariant {
     float getFloat();
     double getDouble();
     char* getCharPtr();
+    WSCbase* getInstancePtr();
 
     void setValue(long);
     void setValue(char*);
     void setValue(double);
+    void setValue(WSCbase*);
 
     long getType();
     char* getTypeName();
@@ -107,10 +149,12 @@ public:
   WSCushort getWidth();
   WSCushort getHeight();
   void update();
+  void exit(long);
 };
 
 extern WSDappDev* WSGIappDev();
 extern int WSGFwsInitialize();
+extern long WSGFdestroyWindow(WSCbase*);
 extern void WSGFdeviceInitialize();
 //extern void WSGFfunctionRegister(char*,void*);
 
@@ -157,6 +201,7 @@ public:
   void setParent(WSCbase*);
   WSCbase* getParent();
   WSCbase* getParentWindow();
+  WSCbase* getChildInstance(char*);
 
   void setInternalObject(WSCbool);
   WSCbool getInternalObject();
@@ -186,6 +231,9 @@ public:
   void* getUserData(char*);
 
   void setVariantData(char*,WSCvariant);
+  void setVariantData(char*,int);
+  void setVariantData(char*,char*);
+  void setVariantData(char*,double);
   WSCvariant& getVariantData(char*);
 
   void execProcedure(char*);
@@ -202,6 +250,31 @@ static WSCbase* getSpecialFocusInstance();
 
 };
 
+class WSDmouse {
+  public:
+    WSDmouse();
+
+    WSCbool getMousePosition(short* x,short* y);
+    WSCbool getMousePosition(short* x,short* y,WSCbase*);
+
+    long getMouseStatus();
+    void setMousePosition(short x, short y);
+    void setMouseCursor(long);
+
+    void  addMouseCursor(long id,long val,char*);
+    char* getMouseCursorName(long id);
+    long  getMouseCursorId(long pos);
+    long  getMouseCursor(long id);
+
+    WSCulong getStatus();
+    void setStatus(WSCulong);
+    WSCulong getTargetBtn();
+    void setTargetBtn(WSCulong);
+    void setMouseFocusClient(WSCbase*);
+    WSCbase* getMouseFocusClient();
+};
+WSDmouse* WSGIappMouse();
+
 class WSCform :public WSCbase{
 public:
   WSCform(WSCbase*,char*);
@@ -698,6 +771,7 @@ class WSCbaseDialog :public WSCwindow{
 public:
   WSCbaseDialog(WSCbase*,char*);
   ~WSCbaseDialog();
+  long getStatus();
   long popup();
 };
 
@@ -1107,45 +1181,45 @@ extern WSCbaseList *WSGIappObjectList();
 //events
 #define  WSEV_HASH_MAX_NUM        32
 #define  WSEV_NONE                -1
-#define  WSEV_INITIALIZE           (long)0
-#define  WSEV_DELETE               (long)1
-#define  WSEV_ACTIVATE             (long)2
-#define  WSEV_VALUE_CH             (long)3
-#define  WSEV_FOCUS_CH             (long)4
-#define  WSEV_VISIBLE_CH           (long)5
-#define  WSEV_SENSITIVE_CH         (long)6
-#define  WSEV_PARENT_VISIBLE_CH    (long)7
-#define  WSEV_PARENT_SENSITIVE_CH  (long)8
-#define  WSEV_EXPOSE               (long)9
-#define  WSEV_RESIZE              (long)10
-#define  WSEV_MOUSE_IN            (long)11
-#define  WSEV_MOUSE_OUT           (long)12
-#define  WSEV_MOUSE_PRESS         (long)13
-#define  WSEV_MOUSE_RELEASE       (long)14
-#define  WSEV_MOUSE_MOVE          (long)15
-#define  WSEV_KEY_PRESS           (long)16
-#define  WSEV_KEY_RELEASE         (long)17
-#define  WSEV_KEY_HOOK            (long)18
-#define  WSEV_MOUSE_DOUBLE_CLICK  (long)19
+#define  WSEV_INITIALIZE           0
+#define  WSEV_DELETE               1
+#define  WSEV_ACTIVATE             2
+#define  WSEV_VALUE_CH             3
+#define  WSEV_FOCUS_CH             4
+#define  WSEV_VISIBLE_CH           5
+#define  WSEV_SENSITIVE_CH         6
+#define  WSEV_PARENT_VISIBLE_CH    7
+#define  WSEV_PARENT_SENSITIVE_CH  8
+#define  WSEV_EXPOSE               9
+#define  WSEV_RESIZE              10
+#define  WSEV_MOUSE_IN            11
+#define  WSEV_MOUSE_OUT           12
+#define  WSEV_MOUSE_PRESS         13
+#define  WSEV_MOUSE_RELEASE       14
+#define  WSEV_MOUSE_MOVE          15
+#define  WSEV_KEY_PRESS           16
+#define  WSEV_KEY_RELEASE         17
+#define  WSEV_KEY_HOOK            18
+#define  WSEV_MOUSE_DOUBLE_CLICK  19
 
-#define  WSEV_SORT                (long)33
-#define  WSEV_GUI_POLICY_CH       (long)34
-#define  WSEV_ITEM_SELECTED       (long)35
-#define  WSEV_STATUS_CH           (long)36
-#define  WSEV_INPUT_FIXED         (long)37
-#define  WSEV_BEGIN               (long)38
-#define  WSEV_END                 (long)39
-#define  WSEV_INCREMENT           (long)40
-#define  WSEV_DECREMENT           (long)41
-#define  WSEV_PAGE_INCREMENT      (long)42
-#define  WSEV_PAGE_DECREMENT      (long)43
-#define  WSEV_SCR_MOUSE_PRESS     (long)44
-#define  WSEV_SCR_MOUSE_RELEASE   (long)45
-#define  WSEV_SCR_MOUSE_MOVE      (long)46
-#define  WSEV_EDIT_MODE_CH        (long)47
-#define  WSEV_SPECIAL_FOCUS_CH    (long)48
-#define  WSEV_CHILD_ADDED         (long)49
-#define  WSEV_SELECTION_CH        (long)50
+#define  WSEV_SORT                33
+#define  WSEV_GUI_POLICY_CH       34
+#define  WSEV_ITEM_SELECTED       35
+#define  WSEV_STATUS_CH           36
+#define  WSEV_INPUT_FIXED         37
+#define  WSEV_BEGIN               38
+#define  WSEV_END                 39
+#define  WSEV_INCREMENT           40
+#define  WSEV_DECREMENT           41
+#define  WSEV_PAGE_INCREMENT      42
+#define  WSEV_PAGE_DECREMENT      43
+#define  WSEV_SCR_MOUSE_PRESS     44
+#define  WSEV_SCR_MOUSE_RELEASE   45
+#define  WSEV_SCR_MOUSE_MOVE      46
+#define  WSEV_EDIT_MODE_CH        47
+#define  WSEV_SPECIAL_FOCUS_CH    48
+#define  WSEV_CHILD_ADDED         49
+#define  WSEV_SELECTION_CH        50
 
 
 //-----------------------------------------------------------------------------
@@ -1692,4 +1766,11 @@ extern WSCbaseList *WSGIappObjectList();
 
 #endif
 
+#define WS_LIST_TREE_OPEN "list-tr-open"
+#define WS_LIST_TREE_OPEN_CH "list-tr-open-ch"
+#define WS_LIST_INDENT_LEVEL "list-indent-level"
+#define WS_LIST_INDENT_STATUS "list-indent-status"
+#define WS_LIST_LABEL_LIST "list-lb-list"
+#define WS_LIST_TOP "list-lb-top"
+
 #endif
