@@ -315,13 +315,26 @@ long WSDwinAppDev::handleEvents(){
   return _msg.wParam;
 }
 long WSDwinAppDev::dispatchEvent(){
+ return _dispatchEvent(True);
+}
+long WSDwinAppDev::processEvent(){
+ return _dispatchEvent(False);
+}
+long WSDwinAppDev::_dispatchEvent(WSCbool wait){
 //  HANDLE hAccelTable;
-  long ret = GetMessage(&_msg,NULL,0,0);
-//  if ( !TranslateAccelerator(_msg.hwnd,(HACCEL__*)hAccelTable,&_msg) ){
+  if (wait != False){
+    long ret = GetMessage(&_msg,NULL,0,0);
+    TranslateMessage(&_msg);
+    DispatchMessage(&_msg);
+    return ret;
+  }else{
+    long ret = PeekMessage(&_msg,NULL,0,0,PM_REMOVE);
+    if (ret != FALSE){
       TranslateMessage(&_msg);
       DispatchMessage(&_msg);
-//  }
-  return ret;
+    }
+    return ret;
+  }
 }
 
 void WSDwinAppDev::setInstanceHandle(HINSTANCE h){
