@@ -144,10 +144,15 @@ long WSDwinsocket::listen(){
     seterr();
     return WS_ERR;
   }
-  int len;
-  if(getsockname(_socket, (struct sockaddr *)&server, &len) < 0){
-    seterr();
-    return WS_ERR;
+  OSVERSIONINFO osvi;
+  osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+  GetVersionEx(&osvi);
+  if (osvi.dwPlatformId == VER_PLATFORM_WIN32_NT){
+    int len;
+    if(getsockname(_socket, (struct sockaddr *)&server, &len) < 0){
+      seterr();
+      return WS_ERR;
+    }
   }
   if ( ::listen(_socket, 5) != 0){
     seterr();
