@@ -60,7 +60,7 @@ WSDwinwinDev::WSDwinwinDev(){
   _resize_sequence = False;
   _shell  = 0;
   _wnd  = 0;
-  _title_bar_style = 0;
+  _title_bar_style = WS_FULL_TITLE;
   _no_frame = 0;
   _no_frame_first_time = 0;
   _requested_top = 0;
@@ -90,7 +90,7 @@ WSDdev* WSDwinwinDev::getVisibleParentDev(){
 long WSDwinwinDev::setValue(long kind,void* data){
   WSDwindowDev::setValue(kind,data);
 
-//  char val;
+  char val;
 //  long vl;
   WSDcolor* color;
   WSDimage* image;
@@ -253,12 +253,13 @@ long WSDwinwinDev::setValue(long kind,void* data){
     case WSDEV_TITLE_BAR:
              _diff_x = -1;
              _diff_y = -1;
+             val = _title_bar_style;
              if (*(char*)data < 0 || *(char*)data > 4){
                _title_bar_style = 0;
              }else{
                _title_bar_style = *(char*)data;
              }
-//WSMFtrace("WSDwinwinDev::setValue XXZZtt1 shell=0x%x t=%d\n",_shell,_title_bar_style);
+printf("WSDwinwinDev::setValue XXZZtt1 shell=0x%x t=%d t-bk=%d\n",_shell,_title_bar_style,val);
              if (_title_bar_style == WS_NO_TITLE){ 
                   _style = WS_POPUP;
                   _style_ex = 0;
@@ -299,8 +300,8 @@ long WSDwinwinDev::setValue(long kind,void* data){
                   _style = WS_POPUP;
                   _style_ex = 0;
              }
-#if 0
-             if (_shell!= 0){
+#if 1
+             if (_shell!= 0 && _title_bar_style != val){
                  destroyWindow();
              }
 #endif
@@ -527,7 +528,7 @@ extern char szAppName[];
     _shell = CreateWindowEx( _style_ex,szAppName,"", _style | WS_CLIPSIBLINGS | WS_CLIPCHILDREN, x,y,w,h,NULL,
                         NULL,WSGIwinAppDev()->getInstanceHandle(),NULL);
     SetWindowLong(_shell,GWL_STYLE,_style | WS_CLIPSIBLINGS | WS_CLIPCHILDREN);
-    SetWindowLong(_shell,GWL_EXSTYLE,_style_ex);
+//    SetWindowLong(_shell,GWL_EXSTYLE,_style_ex);
 
 
   }
