@@ -82,35 +82,126 @@ static long unix_rename(char* old_name,char* new_name){
 long WSDunixFS::rename(char* old_name,char* new_name){
   WSCstring name1(old_name);
   WSCstring name2(new_name);
+#ifdef MacOS
+  if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* utf8_to_macutf8(char*);
+    char* mstr1 = utf8_to_macutf8(
+          name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
+    char* mstr2 = utf8_to_macutf8(
+          name2.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
+    long ret;
+    if (mstr1 != NULL && mstr2 != NULL){
+      ret = unix_rename(mstr1,mstr2);
+    }
+    if (mstr1 != NULL){
+      delete mstr1;
+    }
+    if (mstr2 != NULL){
+      delete mstr2;
+    }
+    return ret;
+  }else{
+    return unix_rename(
+     name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
+     name2.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
+  }
+#else
   return unix_rename(
      name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()),
      name2.getString(WSGIappLocaleSet()->getSystemLocaleEncoding()));
+#endif
 }
 
 long WSDunixFS::deleteFile(char* name){
   WSCstring name1(name);
   char* fn = name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
+#ifdef MacOS
+  if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* utf8_to_macutf8(char*);
+    char* fn2 = utf8_to_macutf8(fn);
+    if (fn2 != NULL){
+      if (remove(fn2) == 0){
+        delete fn2;
+        return WS_NO_ERR;
+      }
+      delete fn2;
+    }else{
+      if (remove(fn) == 0){
+        return WS_NO_ERR;
+      }
+    }
+  }else{
+    if (remove(fn) == 0){
+      return WS_NO_ERR;
+    }
+  }
+#else
   if (remove(fn) == 0){
     return WS_NO_ERR;
   }
+#endif
   return WS_ERR;
 }
 
 long WSDunixFS::createDir(char* name){
   WSCstring name1(name);
   char* fn = name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
+#ifdef MacOS
+  if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* utf8_to_macutf8(char*);
+    char* fn2 = utf8_to_macutf8(fn);
+    if (fn2 != NULL){
+      if (mkdir(fn2,0777) == 0){
+        delete fn2;
+        return WS_NO_ERR;
+      }
+      delete fn2;
+    }else{
+      if (mkdir(fn,0777) == 0){
+        return WS_NO_ERR;
+      }
+    }
+  }else{
+    if (mkdir(fn,0777) == 0){
+      return WS_NO_ERR;
+    }
+  }
+#else
   if (mkdir(fn,0777) == 0){
     return WS_NO_ERR;
   }
+#endif
   return WS_ERR;
 }
 
 long WSDunixFS::deleteDir(char* name){
   WSCstring name1(name);
   char* fn = name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
+#ifdef MacOS
+  if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* utf8_to_macutf8(char*);
+    char* fn2 = utf8_to_macutf8(fn);
+    if (fn2 != NULL){
+      if (rmdir(fn2) == 0){
+        delete fn2;
+        return WS_NO_ERR;
+      }
+      delete fn2;
+    }else{
+      if (rmdir(fn) == 0){
+        return WS_NO_ERR;
+      }
+    }
+  }else{
+    if (rmdir(fn) == 0){
+      return WS_NO_ERR;
+    }
+  }
+#else
   if (rmdir(fn) == 0){
     return WS_NO_ERR;
   }
+#endif
   return WS_ERR;
 }
 #if 0
@@ -135,6 +226,32 @@ long WSDunixFS::check(char* fname){
   char* fn = name1.getString(WSGIappLocaleSet()->getSystemLocaleEncoding());
   struct stat sret;
   long ret = 0;
+#ifdef MacOS
+  char* fn2 = NULL;
+  if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* utf8_to_macutf8(char*);
+    fn2 = utf8_to_macutf8(fn);
+  }else{
+    fn2 = WSGFstrdup(fn);
+  }
+  if (fn2 == NULL){
+    return WS_ERR;
+  }
+  if (stat(fn2,&sret) == -1){
+    delete fn2;
+    return 0;
+  }
+  if ((sret.st_mode & S_IFMT) == S_IFDIR){
+    ret |= WS_FS_DIR;
+  }
+  if (!(sret.st_mode & S_IFREG)){
+    ret |= WS_FS_FILE;
+  }
+  if ( access(fn,W_OK) == -1){
+    ret |= WS_FS_READONLY;
+  }
+  delete fn2;
+#else
   if (stat(fn,&sret) == -1){
     return 0;
   }
@@ -147,6 +264,7 @@ long WSDunixFS::check(char* fname){
   if ( access(fn,W_OK) == -1){
     ret |= WS_FS_READONLY;
   }
+#endif 
   return ret;
 }
 
@@ -184,8 +302,26 @@ WSClistData* WSDunixFS::showDir(char* dname){
     }
     if (sret.st_mode & S_IFDIR){
       WSCstring tmp;
+#ifdef MacOS
+      if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* macutf8_to_utf8(char*);
+        char* t2 = macutf8_to_utf8(finddata->d_name);
+        if (t2 != NULL){
+          tmp.setString(t2,
+                    WSGIappLocaleSet()->getSystemLocaleEncoding());
+          delete t2;
+        }else{
+          tmp.setString(finddata->d_name,
+                    WSGIappLocaleSet()->getSystemLocaleEncoding());
+        }
+      }else{
+        tmp.setString(finddata->d_name,
+                    WSGIappLocaleSet()->getSystemLocaleEncoding());
+      }
+#else
       tmp.setString(finddata->d_name,
                     WSGIappLocaleSet()->getSystemLocaleEncoding());
+#endif
       list->add((void*)WSGFstrdup(tmp.getString()));
     }
   }
@@ -244,8 +380,26 @@ WSClistData* WSDunixFS::showFile(char* dname){
     }
     if (sret.st_mode & S_IFREG){
       WSCstring tmp;
+#ifdef MacOS
+      if (WSGIappLocaleSet()->getSystemLocaleEncoding() == WS_EN_UTF8){
+extern char* macutf8_to_utf8(char*);
+        char* t2 = macutf8_to_utf8(finddata->d_name);
+        if (t2 != NULL){
+          tmp.setString(t2,
+                    WSGIappLocaleSet()->getSystemLocaleEncoding());
+          delete t2;
+        }else{
+          tmp.setString(finddata->d_name,
+                    WSGIappLocaleSet()->getSystemLocaleEncoding());
+        }
+      }else{
+        tmp.setString(finddata->d_name,
+                    WSGIappLocaleSet()->getSystemLocaleEncoding());
+      }
+#else
       tmp.setString(finddata->d_name,
                     WSGIappLocaleSet()->getSystemLocaleEncoding());
+#endif
       list->add((void*)WSGFstrdup(tmp.getString()));
     }
   }
