@@ -420,11 +420,24 @@ long WSDxappDev::handleEvents(){
 }
 
 long WSDxappDev::dispatchEvent(){
+  return _dispatchEvent(True);
+}
+long WSDxappDev::processEvent(){
+  return _dispatchEvent(False);
+}
+long WSDxappDev::_dispatchEvent(WSCbool wait){
 
 static long cnt = 0;
 cnt++;
   XEvent e;
-  XtAppNextEvent(_app_context,&e);
+  if (wait != False){
+    XtAppNextEvent(_app_context,&e);
+  }else{
+    Boolean fl = XtAppPeekEvent(_app_context,&e);
+    if (fl == 0){
+      return WS_NO_ERR;
+    }
+  }
   WSCbool dispatch = True; 
 
 #ifndef KINPUT2
